package com.ruoyi.frequency.report.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.controller.req.ReportReq;
import com.ruoyi.frequency.report.entity.Report;
import com.ruoyi.response.ResponseData;
import com.ruoyi.vo.UserVo;

import java.util.List;

/**
 * 举报用户Service接口
 * 
 * @author liwenlong
 * @date 2023-11-17
 */
public interface ReportService extends IService<Report>
{
    /**
     * 查询举报用户
     * 
     * @param id 举报用户主键
     * @return 举报用户
     */
    public Report selectReportById(Long id);

    /**
     * 查询举报用户列表
     * 
     * @param report 举报用户
     * @return 举报用户集合
     */
    public List<Report> selectReportList(Report report);

    /**
     * 新增举报用户
     * 
     * @param report 举报用户
     * @return 结果
     */
    public int insertReport(Report report);

    /**
     * 修改举报用户
     * 
     * @param report 举报用户
     * @return 结果
     */
    public int updateReport(Report report);

    /**
     * 批量删除举报用户
     * 
     * @param ids 需要删除的举报用户主键集合
     * @return 结果
     */
    public int deleteReportByIds(Long[] ids,Integer delFlag);

    /**
     * 举报处理
     * @param report
     * @return
     */
    AjaxResult handle(Report report);

    /**
     * 举报用户
     * @param req
     * @param userVo
     * @return
     */
    ResponseData report(ReportReq req, UserVo userVo);

}
